##  Fields on Relations
Fields on relations serve as attributes that provide additional information about the relation between two fact sheets.
To create a field on a relation, on the fact sheet configuration page, select a subsection representing a relation, click Add field, then configure the field and save the changes.
